###########
User Guide
###########

In this user guide, you will find detailed descriptions and examples that describe the many capabilities of Swiftest and how to use them.

- Setting up a :doc:`Basic Simulation <basic-simulation>`

- A more in-depth :doc:`Detailed Simulation Setup <detailed-simulation-setup>`

- Understanding the :doc:`Gravitational Harmonics capabilities <gravitational-harmonics>`

.. toctree::
   :maxdepth: 2
   :hidden:

   Basic Simulation <basic-simulation>
   Detailed Simulation Setup <detailed-simulation-setup>
   Gravitational Harmonics <gravitational-harmonics>